@@ -32,6 +32,7 @@ class TestInterpreter(unittest.TestCase):
 
     def test_simple_expr(self):
         # Test the expression interpreter
+        self.assertEquals(self.db.query("general/nothing"), None)
         self.assertEquals(self.db.query("general/answer"), "42")
         self.assertEquals(self.db.query("(general/answer)"), "42")
         self.assertEquals(self.db.query("general/answer + 1"), 43)
@@ -45,6 +46,7 @@ class TestInterpreter(unittest.TestCase):
         # Functions
         self.assertEquals(self.db.query("int(general/answer / 4)"), 10)
         self.assertEquals(self.db.query("round(general/answer / 4)"), 11)
+        self.assertEquals(self.db.query("round(3 * 5 / 2) + 2"), 10)
 
         # Curly braces in expressions
         self.assertEquals(self.db.query("master:{master/type}/num + 3"), 4)
